@@ -230,11 +230,14 @@ class Network(object):
       if len(self.viz['row_nodes']) == 0:
         self.cluster()
 
-        # print('HERE!!!!!!!!!!!!!!!!!!!!!!!!')
+        # add manual_category to viz json
         if 'manual_category' in self.dat:
-          # print('adding manual_category to viz')
           self.viz['manual_category'] = self.dat['manual_category']
 
+        # add pre-z-score data to viz
+        if 'pre_zscore' in self.dat:
+          self.viz['pre_zscore'] = self.dat['pre_zscore']
+
       self.widget_instance = self.widget_class(network = self.export_viz_to_widget(which_viz))
 
       return self.widget_instance
@@ -1148,6 +1151,7 @@ class Network(object):
     try:
       export_dict = {}
       try:
+        # print(json.loads(self.widget_instance.custom_cat))
         export_dict[cat_title] = pd.Series(json.loads(self.widget_instance.custom_cat)[axis][cat_title])
       except:
         print('unable to load category, please check title')
